ports

package
v0.0.0-...-4e57419 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package ports is a generated GoMock package.

Package ports is a generated GoMock package.

Package ports is a generated GoMock package.

Package ports is a generated GoMock package.

Package ports is a generated GoMock package.

Package ports is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DocumentRepository

type DocumentRepository interface {
	Create(ctx context.Context, doc *models.DocumentReference) (*models.DocumentReference, error)
	GetByID(ctx context.Context, id string) (*models.DocumentReference, error)
	GetByIDs(ctx context.Context, ids []string) ([]models.DocumentReference, error)
	Update(ctx context.Context, doc *models.DocumentReference) (*models.DocumentReference, error)
	Delete(ctx context.Context, id string) error
	Search(ctx context.Context, patientID string, limit, offset int) ([]models.DocumentReference, int64, error)
}

type DocumentService

type DocumentService interface {
	CreateDocument(ctx context.Context, doc *models.DocumentReference) (*domain.CreateDocumentResult, error)
	GetDocument(ctx context.Context, id string) (*models.DocumentReference, error)
	DeleteDocument(ctx context.Context, id string) error
	ListDocuments(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.DocumentReference], error)
}

type FileProvider

type FileProvider interface {
	GetPresignedUrls(ctx context.Context, data domain.GetPresignedUrlsRequest) (*domain.PresignedUrlsResponse, error)
	DeleteFile(ctx context.Context, fileId string) error
}

type MockDocumentRepository

type MockDocumentRepository struct {
	// contains filtered or unexported fields
}

MockDocumentRepository is a mock of DocumentRepository interface.

func NewMockDocumentRepository

func NewMockDocumentRepository(ctrl *gomock.Controller) *MockDocumentRepository

NewMockDocumentRepository creates a new mock instance.

func (*MockDocumentRepository) Create

Create mocks base method.

func (*MockDocumentRepository) Delete

func (m *MockDocumentRepository) Delete(ctx context.Context, id string) error

Delete mocks base method.

func (*MockDocumentRepository) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockDocumentRepository) GetByID

GetByID mocks base method.

func (*MockDocumentRepository) GetByIDs

GetByIDs mocks base method.

func (*MockDocumentRepository) Search

func (m *MockDocumentRepository) Search(ctx context.Context, patientID string, limit, offset int) ([]models.DocumentReference, int64, error)

Search mocks base method.

func (*MockDocumentRepository) Update

Update mocks base method.

type MockDocumentRepositoryMockRecorder

type MockDocumentRepositoryMockRecorder struct {
	// contains filtered or unexported fields
}

MockDocumentRepositoryMockRecorder is the mock recorder for MockDocumentRepository.

func (*MockDocumentRepositoryMockRecorder) Create

func (mr *MockDocumentRepositoryMockRecorder) Create(ctx, doc any) *gomock.Call

Create indicates an expected call of Create.

func (*MockDocumentRepositoryMockRecorder) Delete

func (mr *MockDocumentRepositoryMockRecorder) Delete(ctx, id any) *gomock.Call

Delete indicates an expected call of Delete.

func (*MockDocumentRepositoryMockRecorder) GetByID

func (mr *MockDocumentRepositoryMockRecorder) GetByID(ctx, id any) *gomock.Call

GetByID indicates an expected call of GetByID.

func (*MockDocumentRepositoryMockRecorder) GetByIDs

func (mr *MockDocumentRepositoryMockRecorder) GetByIDs(ctx, ids any) *gomock.Call

GetByIDs indicates an expected call of GetByIDs.

func (*MockDocumentRepositoryMockRecorder) Search

func (mr *MockDocumentRepositoryMockRecorder) Search(ctx, patientID, limit, offset any) *gomock.Call

Search indicates an expected call of Search.

func (*MockDocumentRepositoryMockRecorder) Update

func (mr *MockDocumentRepositoryMockRecorder) Update(ctx, doc any) *gomock.Call

Update indicates an expected call of Update.

type MockDocumentService

type MockDocumentService struct {
	// contains filtered or unexported fields
}

MockDocumentService is a mock of DocumentService interface.

func NewMockDocumentService

func NewMockDocumentService(ctrl *gomock.Controller) *MockDocumentService

NewMockDocumentService creates a new mock instance.

func (*MockDocumentService) CreateDocument

CreateDocument mocks base method.

func (*MockDocumentService) DeleteDocument

func (m *MockDocumentService) DeleteDocument(ctx context.Context, id string) error

DeleteDocument mocks base method.

func (*MockDocumentService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockDocumentService) GetDocument

GetDocument mocks base method.

func (*MockDocumentService) ListDocuments

func (m *MockDocumentService) ListDocuments(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.DocumentReference], error)

ListDocuments mocks base method.

type MockDocumentServiceMockRecorder

type MockDocumentServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockDocumentServiceMockRecorder is the mock recorder for MockDocumentService.

func (*MockDocumentServiceMockRecorder) CreateDocument

func (mr *MockDocumentServiceMockRecorder) CreateDocument(ctx, doc any) *gomock.Call

CreateDocument indicates an expected call of CreateDocument.

func (*MockDocumentServiceMockRecorder) DeleteDocument

func (mr *MockDocumentServiceMockRecorder) DeleteDocument(ctx, id any) *gomock.Call

DeleteDocument indicates an expected call of DeleteDocument.

func (*MockDocumentServiceMockRecorder) GetDocument

func (mr *MockDocumentServiceMockRecorder) GetDocument(ctx, id any) *gomock.Call

GetDocument indicates an expected call of GetDocument.

func (*MockDocumentServiceMockRecorder) ListDocuments

func (mr *MockDocumentServiceMockRecorder) ListDocuments(ctx, patientID, limit, offset any) *gomock.Call

ListDocuments indicates an expected call of ListDocuments.

type MockFileProvider

type MockFileProvider struct {
	// contains filtered or unexported fields
}

MockFileProvider is a mock of FileProvider interface.

func NewMockFileProvider

func NewMockFileProvider(ctrl *gomock.Controller) *MockFileProvider

NewMockFileProvider creates a new mock instance.

func (*MockFileProvider) DeleteFile

func (m *MockFileProvider) DeleteFile(ctx context.Context, fileId string) error

DeleteFile mocks base method.

func (*MockFileProvider) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockFileProvider) GetPresignedUrls

GetPresignedUrls mocks base method.

type MockFileProviderMockRecorder

type MockFileProviderMockRecorder struct {
	// contains filtered or unexported fields
}

MockFileProviderMockRecorder is the mock recorder for MockFileProvider.

func (*MockFileProviderMockRecorder) DeleteFile

func (mr *MockFileProviderMockRecorder) DeleteFile(ctx, fileId any) *gomock.Call

DeleteFile indicates an expected call of DeleteFile.

func (*MockFileProviderMockRecorder) GetPresignedUrls

func (mr *MockFileProviderMockRecorder) GetPresignedUrls(ctx, data any) *gomock.Call

GetPresignedUrls indicates an expected call of GetPresignedUrls.

type MockObservationRepository

type MockObservationRepository struct {
	// contains filtered or unexported fields
}

MockObservationRepository is a mock of ObservationRepository interface.

func NewMockObservationRepository

func NewMockObservationRepository(ctrl *gomock.Controller) *MockObservationRepository

NewMockObservationRepository creates a new mock instance.

func (*MockObservationRepository) Create

Create mocks base method.

func (*MockObservationRepository) Delete

Delete mocks base method.

func (*MockObservationRepository) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockObservationRepository) GetByID

GetByID mocks base method.

func (*MockObservationRepository) GetByIDs

GetByIDs mocks base method.

func (*MockObservationRepository) Search

func (m *MockObservationRepository) Search(ctx context.Context, patientID string, limit, offset int) ([]models.Observation, int64, error)

Search mocks base method.

func (*MockObservationRepository) Update

Update mocks base method.

type MockObservationRepositoryMockRecorder

type MockObservationRepositoryMockRecorder struct {
	// contains filtered or unexported fields
}

MockObservationRepositoryMockRecorder is the mock recorder for MockObservationRepository.

func (*MockObservationRepositoryMockRecorder) Create

func (mr *MockObservationRepositoryMockRecorder) Create(ctx, obs any) *gomock.Call

Create indicates an expected call of Create.

func (*MockObservationRepositoryMockRecorder) Delete

Delete indicates an expected call of Delete.

func (*MockObservationRepositoryMockRecorder) GetByID

func (mr *MockObservationRepositoryMockRecorder) GetByID(ctx, id any) *gomock.Call

GetByID indicates an expected call of GetByID.

func (*MockObservationRepositoryMockRecorder) GetByIDs

func (mr *MockObservationRepositoryMockRecorder) GetByIDs(ctx, ids any) *gomock.Call

GetByIDs indicates an expected call of GetByIDs.

func (*MockObservationRepositoryMockRecorder) Search

func (mr *MockObservationRepositoryMockRecorder) Search(ctx, patientID, limit, offset any) *gomock.Call

Search indicates an expected call of Search.

func (*MockObservationRepositoryMockRecorder) Update

func (mr *MockObservationRepositoryMockRecorder) Update(ctx, obs any) *gomock.Call

Update indicates an expected call of Update.

type MockObservationService

type MockObservationService struct {
	// contains filtered or unexported fields
}

MockObservationService is a mock of ObservationService interface.

func NewMockObservationService

func NewMockObservationService(ctrl *gomock.Controller) *MockObservationService

NewMockObservationService creates a new mock instance.

func (*MockObservationService) Create

Create mocks base method.

func (*MockObservationService) Delete

func (m *MockObservationService) Delete(ctx context.Context, id string) error

Delete mocks base method.

func (*MockObservationService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockObservationService) Get

Get mocks base method.

func (*MockObservationService) List

func (m *MockObservationService) List(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.Observation], error)

List mocks base method.

func (*MockObservationService) Update

Update mocks base method.

type MockObservationServiceMockRecorder

type MockObservationServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockObservationServiceMockRecorder is the mock recorder for MockObservationService.

func (*MockObservationServiceMockRecorder) Create

func (mr *MockObservationServiceMockRecorder) Create(ctx, obs any) *gomock.Call

Create indicates an expected call of Create.

func (*MockObservationServiceMockRecorder) Delete

func (mr *MockObservationServiceMockRecorder) Delete(ctx, id any) *gomock.Call

Delete indicates an expected call of Delete.

func (*MockObservationServiceMockRecorder) Get

Get indicates an expected call of Get.

func (*MockObservationServiceMockRecorder) List

func (mr *MockObservationServiceMockRecorder) List(ctx, patientID, limit, offset any) *gomock.Call

List indicates an expected call of List.

func (*MockObservationServiceMockRecorder) Update

func (mr *MockObservationServiceMockRecorder) Update(ctx, obs any) *gomock.Call

Update indicates an expected call of Update.

type MockPatientRepository

type MockPatientRepository struct {
	// contains filtered or unexported fields
}

MockPatientRepository is a mock of PatientRepository interface.

func NewMockPatientRepository

func NewMockPatientRepository(ctrl *gomock.Controller) *MockPatientRepository

NewMockPatientRepository creates a new mock instance.

func (*MockPatientRepository) Create

func (m *MockPatientRepository) Create(ctx context.Context, patient *models.Patient) (*models.Patient, error)

Create mocks base method.

func (*MockPatientRepository) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockPatientRepository) GetByID

GetByID mocks base method.

func (*MockPatientRepository) Update

func (m *MockPatientRepository) Update(ctx context.Context, patient *models.Patient) (*models.Patient, error)

Update mocks base method.

type MockPatientRepositoryMockRecorder

type MockPatientRepositoryMockRecorder struct {
	// contains filtered or unexported fields
}

MockPatientRepositoryMockRecorder is the mock recorder for MockPatientRepository.

func (*MockPatientRepositoryMockRecorder) Create

func (mr *MockPatientRepositoryMockRecorder) Create(ctx, patient any) *gomock.Call

Create indicates an expected call of Create.

func (*MockPatientRepositoryMockRecorder) GetByID

func (mr *MockPatientRepositoryMockRecorder) GetByID(ctx, id any) *gomock.Call

GetByID indicates an expected call of GetByID.

func (*MockPatientRepositoryMockRecorder) Update

func (mr *MockPatientRepositoryMockRecorder) Update(ctx, patient any) *gomock.Call

Update indicates an expected call of Update.

type MockPatientService

type MockPatientService struct {
	// contains filtered or unexported fields
}

MockPatientService is a mock of PatientService interface.

func NewMockPatientService

func NewMockPatientService(ctrl *gomock.Controller) *MockPatientService

NewMockPatientService creates a new mock instance.

func (*MockPatientService) Create

func (m *MockPatientService) Create(ctx context.Context, patient *models.Patient) (*models.Patient, error)

Create mocks base method.

func (*MockPatientService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockPatientService) Get

Get mocks base method.

func (*MockPatientService) Update

func (m *MockPatientService) Update(ctx context.Context, patient *models.Patient) (*models.Patient, error)

Update mocks base method.

type MockPatientServiceMockRecorder

type MockPatientServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockPatientServiceMockRecorder is the mock recorder for MockPatientService.

func (*MockPatientServiceMockRecorder) Create

func (mr *MockPatientServiceMockRecorder) Create(ctx, patient any) *gomock.Call

Create indicates an expected call of Create.

func (*MockPatientServiceMockRecorder) Get

func (mr *MockPatientServiceMockRecorder) Get(ctx, id any) *gomock.Call

Get indicates an expected call of Get.

func (*MockPatientServiceMockRecorder) Update

func (mr *MockPatientServiceMockRecorder) Update(ctx, patient any) *gomock.Call

Update indicates an expected call of Update.

type MockShareService

type MockShareService struct {
	// contains filtered or unexported fields
}

MockShareService is a mock of ShareService interface.

func NewMockShareService

func NewMockShareService(ctrl *gomock.Controller) *MockShareService

NewMockShareService creates a new mock instance.

func (*MockShareService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockShareService) GetSharedResources

func (m *MockShareService) GetSharedResources(ctx context.Context) (*domain.SharedResourcesResponse, error)

GetSharedResources mocks base method.

func (*MockShareService) Share

Share mocks base method.

type MockShareServiceMockRecorder

type MockShareServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockShareServiceMockRecorder is the mock recorder for MockShareService.

func (*MockShareServiceMockRecorder) GetSharedResources

func (mr *MockShareServiceMockRecorder) GetSharedResources(ctx any) *gomock.Call

GetSharedResources indicates an expected call of GetSharedResources.

func (*MockShareServiceMockRecorder) Share

func (mr *MockShareServiceMockRecorder) Share(ctx, req any) *gomock.Call

Share indicates an expected call of Share.

type MockTmpAccessClient

type MockTmpAccessClient struct {
	// contains filtered or unexported fields
}

MockTmpAccessClient is a mock of TmpAccessClient interface.

func NewMockTmpAccessClient

func NewMockTmpAccessClient(ctrl *gomock.Controller) *MockTmpAccessClient

NewMockTmpAccessClient creates a new mock instance.

func (*MockTmpAccessClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockTmpAccessClient) GenerateTmpToken

GenerateTmpToken mocks base method.

type MockTmpAccessClientMockRecorder

type MockTmpAccessClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockTmpAccessClientMockRecorder is the mock recorder for MockTmpAccessClient.

func (*MockTmpAccessClientMockRecorder) GenerateTmpToken

func (mr *MockTmpAccessClientMockRecorder) GenerateTmpToken(ctx, data any) *gomock.Call

GenerateTmpToken indicates an expected call of GenerateTmpToken.

type ObservationRepository

type ObservationRepository interface {
	Create(ctx context.Context, obs *models.Observation) (*models.Observation, error)
	GetByID(ctx context.Context, id string) (*models.Observation, error)
	GetByIDs(ctx context.Context, ids []string) ([]models.Observation, error)
	Update(ctx context.Context, obs *models.Observation) (*models.Observation, error)
	Delete(ctx context.Context, id string) error
	Search(ctx context.Context, patientID string, limit, offset int) ([]models.Observation, int64, error)
}

type ObservationService

type ObservationService interface {
	Create(ctx context.Context, obs *models.Observation) (*models.Observation, error)
	Get(ctx context.Context, id string) (*models.Observation, error)
	Update(ctx context.Context, obs *models.Observation) (*models.Observation, error)
	Delete(ctx context.Context, id string) error
	List(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.Observation], error)
}

type PatientRepository

type PatientRepository interface {
	Create(ctx context.Context, patient *models.Patient) (*models.Patient, error)
	GetByID(ctx context.Context, id string) (*models.Patient, error)
	Update(ctx context.Context, patient *models.Patient) (*models.Patient, error)
}

type PatientService

type PatientService interface {
	Create(ctx context.Context, patient *models.Patient) (*models.Patient, error)
	Get(ctx context.Context, id string) (*models.Patient, error)
	Update(ctx context.Context, patient *models.Patient) (*models.Patient, error)
}

type ShareService

type ShareService interface {
	Share(ctx context.Context, req domain.ShareRequest) (*domain.ShareResponse, error)
	GetSharedResources(ctx context.Context) (*domain.SharedResourcesResponse, error)
}

type TmpAccessClient

type TmpAccessClient interface {
	GenerateTmpToken(ctx context.Context, data domain.GenerateTmpTokenRequest) (*domain.GenerateTmpTokenResponse, error)
}

Jump to