proto

package module
v0.0.0-...-4e57419 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: MIT Imports: 9 Imported by: 1

Documentation

Index

Constants

const (
	AuthIntegration_CreatePatient_FullMethodName = "/proto.AuthIntegration/CreatePatient"
)

Variables

var AuthIntegration_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "proto.AuthIntegration",
	HandlerType: (*AuthIntegrationServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreatePatient",
			Handler:    _AuthIntegration_CreatePatient_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "auth.proto",
}

AuthIntegration_ServiceDesc is the grpc.ServiceDesc for AuthIntegration service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAuthIntegrationServer

func RegisterAuthIntegrationServer(s grpc.ServiceRegistrar, srv AuthIntegrationServer)

Types

type AuthIntegrationClient

type AuthIntegrationClient interface {
	CreatePatient(ctx context.Context, in *CreatePatientRequest, opts ...grpc.CallOption) (*CreatePatientResponse, error)
}

AuthIntegrationClient is the client API for AuthIntegration service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AuthIntegrationServer

type AuthIntegrationServer interface {
	CreatePatient(context.Context, *CreatePatientRequest) (*CreatePatientResponse, error)
	// contains filtered or unexported methods
}

AuthIntegrationServer is the server API for AuthIntegration service. All implementations must embed UnimplementedAuthIntegrationServer for forward compatibility.

type CreatePatientRequest

type CreatePatientRequest struct {
	Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
	// contains filtered or unexported fields
}

func (*CreatePatientRequest) Descriptor deprecated

func (*CreatePatientRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreatePatientRequest.ProtoReflect.Descriptor instead.

func (*CreatePatientRequest) GetEmail

func (x *CreatePatientRequest) GetEmail() string

func (*CreatePatientRequest) ProtoMessage

func (*CreatePatientRequest) ProtoMessage()

func (*CreatePatientRequest) ProtoReflect

func (x *CreatePatientRequest) ProtoReflect() protoreflect.Message

func (*CreatePatientRequest) Reset

func (x *CreatePatientRequest) Reset()

func (*CreatePatientRequest) String

func (x *CreatePatientRequest) String() string

type CreatePatientResponse

type CreatePatientResponse struct {
	PatientId string   `protobuf:"bytes,1,opt,name=patient_id,json=patientId,proto3" json:"patient_id,omitempty"`
	Scopes    []string `protobuf:"bytes,2,rep,name=scopes,proto3" json:"scopes,omitempty"`
	// contains filtered or unexported fields
}

func (*CreatePatientResponse) Descriptor deprecated

func (*CreatePatientResponse) Descriptor() ([]byte, []int)

Deprecated: Use CreatePatientResponse.ProtoReflect.Descriptor instead.

func (*CreatePatientResponse) GetPatientId

func (x *CreatePatientResponse) GetPatientId() string

func (*CreatePatientResponse) GetScopes

func (x *CreatePatientResponse) GetScopes() []string

func (*CreatePatientResponse) ProtoMessage

func (*CreatePatientResponse) ProtoMessage()

func (*CreatePatientResponse) ProtoReflect

func (x *CreatePatientResponse) ProtoReflect() protoreflect.Message

func (*CreatePatientResponse) Reset

func (x *CreatePatientResponse) Reset()

func (*CreatePatientResponse) String

func (x *CreatePatientResponse) String() string

type UnimplementedAuthIntegrationServer

type UnimplementedAuthIntegrationServer struct{}

UnimplementedAuthIntegrationServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAuthIntegrationServer) CreatePatient

type UnsafeAuthIntegrationServer

type UnsafeAuthIntegrationServer interface {
	// contains filtered or unexported methods
}

UnsafeAuthIntegrationServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthIntegrationServer will result in compilation errors.

Jump to