Documentation
¶
Overview ¶
Package ports is a generated GoMock package.
Package ports is a generated GoMock package.
Package ports is a generated GoMock package.
Package ports is a generated GoMock package.
Package ports is a generated GoMock package.
Package ports is a generated GoMock package.
Index ¶
- type DocumentRepository
- type DocumentService
- type FileProvider
- type MockDocumentRepository
- func (m *MockDocumentRepository) Create(ctx context.Context, doc *models.DocumentReference) (*models.DocumentReference, error)
- func (m *MockDocumentRepository) Delete(ctx context.Context, id string) error
- func (m *MockDocumentRepository) EXPECT() *MockDocumentRepositoryMockRecorder
- func (m *MockDocumentRepository) GetByID(ctx context.Context, id string) (*models.DocumentReference, error)
- func (m *MockDocumentRepository) GetByIDs(ctx context.Context, ids []string) ([]models.DocumentReference, error)
- func (m *MockDocumentRepository) Search(ctx context.Context, patientID string, limit, offset int) ([]models.DocumentReference, int64, error)
- func (m *MockDocumentRepository) Update(ctx context.Context, doc *models.DocumentReference) (*models.DocumentReference, error)
- type MockDocumentRepositoryMockRecorder
- func (mr *MockDocumentRepositoryMockRecorder) Create(ctx, doc any) *gomock.Call
- func (mr *MockDocumentRepositoryMockRecorder) Delete(ctx, id any) *gomock.Call
- func (mr *MockDocumentRepositoryMockRecorder) GetByID(ctx, id any) *gomock.Call
- func (mr *MockDocumentRepositoryMockRecorder) GetByIDs(ctx, ids any) *gomock.Call
- func (mr *MockDocumentRepositoryMockRecorder) Search(ctx, patientID, limit, offset any) *gomock.Call
- func (mr *MockDocumentRepositoryMockRecorder) Update(ctx, doc any) *gomock.Call
- type MockDocumentService
- func (m *MockDocumentService) CreateDocument(ctx context.Context, doc *models.DocumentReference) (*domain.CreateDocumentResult, error)
- func (m *MockDocumentService) DeleteDocument(ctx context.Context, id string) error
- func (m *MockDocumentService) EXPECT() *MockDocumentServiceMockRecorder
- func (m *MockDocumentService) GetDocument(ctx context.Context, id string) (*models.DocumentReference, error)
- func (m *MockDocumentService) ListDocuments(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.DocumentReference], error)
- type MockDocumentServiceMockRecorder
- func (mr *MockDocumentServiceMockRecorder) CreateDocument(ctx, doc any) *gomock.Call
- func (mr *MockDocumentServiceMockRecorder) DeleteDocument(ctx, id any) *gomock.Call
- func (mr *MockDocumentServiceMockRecorder) GetDocument(ctx, id any) *gomock.Call
- func (mr *MockDocumentServiceMockRecorder) ListDocuments(ctx, patientID, limit, offset any) *gomock.Call
- type MockFileProvider
- type MockFileProviderMockRecorder
- type MockObservationRepository
- func (m *MockObservationRepository) Create(ctx context.Context, obs *models.Observation) (*models.Observation, error)
- func (m *MockObservationRepository) Delete(ctx context.Context, id string) error
- func (m *MockObservationRepository) EXPECT() *MockObservationRepositoryMockRecorder
- func (m *MockObservationRepository) GetByID(ctx context.Context, id string) (*models.Observation, error)
- func (m *MockObservationRepository) GetByIDs(ctx context.Context, ids []string) ([]models.Observation, error)
- func (m *MockObservationRepository) Search(ctx context.Context, patientID string, limit, offset int) ([]models.Observation, int64, error)
- func (m *MockObservationRepository) Update(ctx context.Context, obs *models.Observation) (*models.Observation, error)
- type MockObservationRepositoryMockRecorder
- func (mr *MockObservationRepositoryMockRecorder) Create(ctx, obs any) *gomock.Call
- func (mr *MockObservationRepositoryMockRecorder) Delete(ctx, id any) *gomock.Call
- func (mr *MockObservationRepositoryMockRecorder) GetByID(ctx, id any) *gomock.Call
- func (mr *MockObservationRepositoryMockRecorder) GetByIDs(ctx, ids any) *gomock.Call
- func (mr *MockObservationRepositoryMockRecorder) Search(ctx, patientID, limit, offset any) *gomock.Call
- func (mr *MockObservationRepositoryMockRecorder) Update(ctx, obs any) *gomock.Call
- type MockObservationService
- func (m *MockObservationService) Create(ctx context.Context, obs *models.Observation) (*models.Observation, error)
- func (m *MockObservationService) Delete(ctx context.Context, id string) error
- func (m *MockObservationService) EXPECT() *MockObservationServiceMockRecorder
- func (m *MockObservationService) Get(ctx context.Context, id string) (*models.Observation, error)
- func (m *MockObservationService) List(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.Observation], error)
- func (m *MockObservationService) Update(ctx context.Context, obs *models.Observation) (*models.Observation, error)
- type MockObservationServiceMockRecorder
- func (mr *MockObservationServiceMockRecorder) Create(ctx, obs any) *gomock.Call
- func (mr *MockObservationServiceMockRecorder) Delete(ctx, id any) *gomock.Call
- func (mr *MockObservationServiceMockRecorder) Get(ctx, id any) *gomock.Call
- func (mr *MockObservationServiceMockRecorder) List(ctx, patientID, limit, offset any) *gomock.Call
- func (mr *MockObservationServiceMockRecorder) Update(ctx, obs any) *gomock.Call
- type MockPatientRepository
- func (m *MockPatientRepository) Create(ctx context.Context, patient *models.Patient) (*models.Patient, error)
- func (m *MockPatientRepository) EXPECT() *MockPatientRepositoryMockRecorder
- func (m *MockPatientRepository) GetByID(ctx context.Context, id string) (*models.Patient, error)
- func (m *MockPatientRepository) Update(ctx context.Context, patient *models.Patient) (*models.Patient, error)
- type MockPatientRepositoryMockRecorder
- type MockPatientService
- func (m *MockPatientService) Create(ctx context.Context, patient *models.Patient) (*models.Patient, error)
- func (m *MockPatientService) EXPECT() *MockPatientServiceMockRecorder
- func (m *MockPatientService) Get(ctx context.Context, id string) (*models.Patient, error)
- func (m *MockPatientService) Update(ctx context.Context, patient *models.Patient) (*models.Patient, error)
- type MockPatientServiceMockRecorder
- type MockShareService
- type MockShareServiceMockRecorder
- type MockTmpAccessClient
- type MockTmpAccessClientMockRecorder
- type ObservationRepository
- type ObservationService
- type PatientRepository
- type PatientService
- type ShareService
- type TmpAccessClient
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DocumentRepository ¶
type DocumentRepository interface {
Create(ctx context.Context, doc *models.DocumentReference) (*models.DocumentReference, error)
GetByID(ctx context.Context, id string) (*models.DocumentReference, error)
GetByIDs(ctx context.Context, ids []string) ([]models.DocumentReference, error)
Update(ctx context.Context, doc *models.DocumentReference) (*models.DocumentReference, error)
Delete(ctx context.Context, id string) error
Search(ctx context.Context, patientID string, limit, offset int) ([]models.DocumentReference, int64, error)
}
type DocumentService ¶
type DocumentService interface {
CreateDocument(ctx context.Context, doc *models.DocumentReference) (*domain.CreateDocumentResult, error)
GetDocument(ctx context.Context, id string) (*models.DocumentReference, error)
DeleteDocument(ctx context.Context, id string) error
ListDocuments(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.DocumentReference], error)
}
type FileProvider ¶
type MockDocumentRepository ¶
type MockDocumentRepository struct {
// contains filtered or unexported fields
}
MockDocumentRepository is a mock of DocumentRepository interface.
func NewMockDocumentRepository ¶
func NewMockDocumentRepository(ctrl *gomock.Controller) *MockDocumentRepository
NewMockDocumentRepository creates a new mock instance.
func (*MockDocumentRepository) Create ¶
func (m *MockDocumentRepository) Create(ctx context.Context, doc *models.DocumentReference) (*models.DocumentReference, error)
Create mocks base method.
func (*MockDocumentRepository) Delete ¶
func (m *MockDocumentRepository) Delete(ctx context.Context, id string) error
Delete mocks base method.
func (*MockDocumentRepository) EXPECT ¶
func (m *MockDocumentRepository) EXPECT() *MockDocumentRepositoryMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockDocumentRepository) GetByID ¶
func (m *MockDocumentRepository) GetByID(ctx context.Context, id string) (*models.DocumentReference, error)
GetByID mocks base method.
func (*MockDocumentRepository) GetByIDs ¶
func (m *MockDocumentRepository) GetByIDs(ctx context.Context, ids []string) ([]models.DocumentReference, error)
GetByIDs mocks base method.
func (*MockDocumentRepository) Search ¶
func (m *MockDocumentRepository) Search(ctx context.Context, patientID string, limit, offset int) ([]models.DocumentReference, int64, error)
Search mocks base method.
func (*MockDocumentRepository) Update ¶
func (m *MockDocumentRepository) Update(ctx context.Context, doc *models.DocumentReference) (*models.DocumentReference, error)
Update mocks base method.
type MockDocumentRepositoryMockRecorder ¶
type MockDocumentRepositoryMockRecorder struct {
// contains filtered or unexported fields
}
MockDocumentRepositoryMockRecorder is the mock recorder for MockDocumentRepository.
func (*MockDocumentRepositoryMockRecorder) Create ¶
func (mr *MockDocumentRepositoryMockRecorder) Create(ctx, doc any) *gomock.Call
Create indicates an expected call of Create.
func (*MockDocumentRepositoryMockRecorder) Delete ¶
func (mr *MockDocumentRepositoryMockRecorder) Delete(ctx, id any) *gomock.Call
Delete indicates an expected call of Delete.
func (*MockDocumentRepositoryMockRecorder) GetByID ¶
func (mr *MockDocumentRepositoryMockRecorder) GetByID(ctx, id any) *gomock.Call
GetByID indicates an expected call of GetByID.
func (*MockDocumentRepositoryMockRecorder) GetByIDs ¶
func (mr *MockDocumentRepositoryMockRecorder) GetByIDs(ctx, ids any) *gomock.Call
GetByIDs indicates an expected call of GetByIDs.
type MockDocumentService ¶
type MockDocumentService struct {
// contains filtered or unexported fields
}
MockDocumentService is a mock of DocumentService interface.
func NewMockDocumentService ¶
func NewMockDocumentService(ctrl *gomock.Controller) *MockDocumentService
NewMockDocumentService creates a new mock instance.
func (*MockDocumentService) CreateDocument ¶
func (m *MockDocumentService) CreateDocument(ctx context.Context, doc *models.DocumentReference) (*domain.CreateDocumentResult, error)
CreateDocument mocks base method.
func (*MockDocumentService) DeleteDocument ¶
func (m *MockDocumentService) DeleteDocument(ctx context.Context, id string) error
DeleteDocument mocks base method.
func (*MockDocumentService) EXPECT ¶
func (m *MockDocumentService) EXPECT() *MockDocumentServiceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockDocumentService) GetDocument ¶
func (m *MockDocumentService) GetDocument(ctx context.Context, id string) (*models.DocumentReference, error)
GetDocument mocks base method.
func (*MockDocumentService) ListDocuments ¶
func (m *MockDocumentService) ListDocuments(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.DocumentReference], error)
ListDocuments mocks base method.
type MockDocumentServiceMockRecorder ¶
type MockDocumentServiceMockRecorder struct {
// contains filtered or unexported fields
}
MockDocumentServiceMockRecorder is the mock recorder for MockDocumentService.
func (*MockDocumentServiceMockRecorder) CreateDocument ¶
func (mr *MockDocumentServiceMockRecorder) CreateDocument(ctx, doc any) *gomock.Call
CreateDocument indicates an expected call of CreateDocument.
func (*MockDocumentServiceMockRecorder) DeleteDocument ¶
func (mr *MockDocumentServiceMockRecorder) DeleteDocument(ctx, id any) *gomock.Call
DeleteDocument indicates an expected call of DeleteDocument.
func (*MockDocumentServiceMockRecorder) GetDocument ¶
func (mr *MockDocumentServiceMockRecorder) GetDocument(ctx, id any) *gomock.Call
GetDocument indicates an expected call of GetDocument.
func (*MockDocumentServiceMockRecorder) ListDocuments ¶
func (mr *MockDocumentServiceMockRecorder) ListDocuments(ctx, patientID, limit, offset any) *gomock.Call
ListDocuments indicates an expected call of ListDocuments.
type MockFileProvider ¶
type MockFileProvider struct {
// contains filtered or unexported fields
}
MockFileProvider is a mock of FileProvider interface.
func NewMockFileProvider ¶
func NewMockFileProvider(ctrl *gomock.Controller) *MockFileProvider
NewMockFileProvider creates a new mock instance.
func (*MockFileProvider) DeleteFile ¶
func (m *MockFileProvider) DeleteFile(ctx context.Context, fileId string) error
DeleteFile mocks base method.
func (*MockFileProvider) EXPECT ¶
func (m *MockFileProvider) EXPECT() *MockFileProviderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockFileProvider) GetPresignedUrls ¶
func (m *MockFileProvider) GetPresignedUrls(ctx context.Context, data domain.GetPresignedUrlsRequest) (*domain.PresignedUrlsResponse, error)
GetPresignedUrls mocks base method.
type MockFileProviderMockRecorder ¶
type MockFileProviderMockRecorder struct {
// contains filtered or unexported fields
}
MockFileProviderMockRecorder is the mock recorder for MockFileProvider.
func (*MockFileProviderMockRecorder) DeleteFile ¶
func (mr *MockFileProviderMockRecorder) DeleteFile(ctx, fileId any) *gomock.Call
DeleteFile indicates an expected call of DeleteFile.
func (*MockFileProviderMockRecorder) GetPresignedUrls ¶
func (mr *MockFileProviderMockRecorder) GetPresignedUrls(ctx, data any) *gomock.Call
GetPresignedUrls indicates an expected call of GetPresignedUrls.
type MockObservationRepository ¶
type MockObservationRepository struct {
// contains filtered or unexported fields
}
MockObservationRepository is a mock of ObservationRepository interface.
func NewMockObservationRepository ¶
func NewMockObservationRepository(ctrl *gomock.Controller) *MockObservationRepository
NewMockObservationRepository creates a new mock instance.
func (*MockObservationRepository) Create ¶
func (m *MockObservationRepository) Create(ctx context.Context, obs *models.Observation) (*models.Observation, error)
Create mocks base method.
func (*MockObservationRepository) Delete ¶
func (m *MockObservationRepository) Delete(ctx context.Context, id string) error
Delete mocks base method.
func (*MockObservationRepository) EXPECT ¶
func (m *MockObservationRepository) EXPECT() *MockObservationRepositoryMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockObservationRepository) GetByID ¶
func (m *MockObservationRepository) GetByID(ctx context.Context, id string) (*models.Observation, error)
GetByID mocks base method.
func (*MockObservationRepository) GetByIDs ¶
func (m *MockObservationRepository) GetByIDs(ctx context.Context, ids []string) ([]models.Observation, error)
GetByIDs mocks base method.
func (*MockObservationRepository) Search ¶
func (m *MockObservationRepository) Search(ctx context.Context, patientID string, limit, offset int) ([]models.Observation, int64, error)
Search mocks base method.
func (*MockObservationRepository) Update ¶
func (m *MockObservationRepository) Update(ctx context.Context, obs *models.Observation) (*models.Observation, error)
Update mocks base method.
type MockObservationRepositoryMockRecorder ¶
type MockObservationRepositoryMockRecorder struct {
// contains filtered or unexported fields
}
MockObservationRepositoryMockRecorder is the mock recorder for MockObservationRepository.
func (*MockObservationRepositoryMockRecorder) Create ¶
func (mr *MockObservationRepositoryMockRecorder) Create(ctx, obs any) *gomock.Call
Create indicates an expected call of Create.
func (*MockObservationRepositoryMockRecorder) Delete ¶
func (mr *MockObservationRepositoryMockRecorder) Delete(ctx, id any) *gomock.Call
Delete indicates an expected call of Delete.
func (*MockObservationRepositoryMockRecorder) GetByID ¶
func (mr *MockObservationRepositoryMockRecorder) GetByID(ctx, id any) *gomock.Call
GetByID indicates an expected call of GetByID.
func (*MockObservationRepositoryMockRecorder) GetByIDs ¶
func (mr *MockObservationRepositoryMockRecorder) GetByIDs(ctx, ids any) *gomock.Call
GetByIDs indicates an expected call of GetByIDs.
type MockObservationService ¶
type MockObservationService struct {
// contains filtered or unexported fields
}
MockObservationService is a mock of ObservationService interface.
func NewMockObservationService ¶
func NewMockObservationService(ctrl *gomock.Controller) *MockObservationService
NewMockObservationService creates a new mock instance.
func (*MockObservationService) Create ¶
func (m *MockObservationService) Create(ctx context.Context, obs *models.Observation) (*models.Observation, error)
Create mocks base method.
func (*MockObservationService) Delete ¶
func (m *MockObservationService) Delete(ctx context.Context, id string) error
Delete mocks base method.
func (*MockObservationService) EXPECT ¶
func (m *MockObservationService) EXPECT() *MockObservationServiceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockObservationService) Get ¶
func (m *MockObservationService) Get(ctx context.Context, id string) (*models.Observation, error)
Get mocks base method.
func (*MockObservationService) List ¶
func (m *MockObservationService) List(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.Observation], error)
List mocks base method.
func (*MockObservationService) Update ¶
func (m *MockObservationService) Update(ctx context.Context, obs *models.Observation) (*models.Observation, error)
Update mocks base method.
type MockObservationServiceMockRecorder ¶
type MockObservationServiceMockRecorder struct {
// contains filtered or unexported fields
}
MockObservationServiceMockRecorder is the mock recorder for MockObservationService.
func (*MockObservationServiceMockRecorder) Create ¶
func (mr *MockObservationServiceMockRecorder) Create(ctx, obs any) *gomock.Call
Create indicates an expected call of Create.
func (*MockObservationServiceMockRecorder) Delete ¶
func (mr *MockObservationServiceMockRecorder) Delete(ctx, id any) *gomock.Call
Delete indicates an expected call of Delete.
func (*MockObservationServiceMockRecorder) Get ¶
func (mr *MockObservationServiceMockRecorder) Get(ctx, id any) *gomock.Call
Get indicates an expected call of Get.
type MockPatientRepository ¶
type MockPatientRepository struct {
// contains filtered or unexported fields
}
MockPatientRepository is a mock of PatientRepository interface.
func NewMockPatientRepository ¶
func NewMockPatientRepository(ctrl *gomock.Controller) *MockPatientRepository
NewMockPatientRepository creates a new mock instance.
func (*MockPatientRepository) Create ¶
func (m *MockPatientRepository) Create(ctx context.Context, patient *models.Patient) (*models.Patient, error)
Create mocks base method.
func (*MockPatientRepository) EXPECT ¶
func (m *MockPatientRepository) EXPECT() *MockPatientRepositoryMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockPatientRepositoryMockRecorder ¶
type MockPatientRepositoryMockRecorder struct {
// contains filtered or unexported fields
}
MockPatientRepositoryMockRecorder is the mock recorder for MockPatientRepository.
func (*MockPatientRepositoryMockRecorder) Create ¶
func (mr *MockPatientRepositoryMockRecorder) Create(ctx, patient any) *gomock.Call
Create indicates an expected call of Create.
type MockPatientService ¶
type MockPatientService struct {
// contains filtered or unexported fields
}
MockPatientService is a mock of PatientService interface.
func NewMockPatientService ¶
func NewMockPatientService(ctrl *gomock.Controller) *MockPatientService
NewMockPatientService creates a new mock instance.
func (*MockPatientService) Create ¶
func (m *MockPatientService) Create(ctx context.Context, patient *models.Patient) (*models.Patient, error)
Create mocks base method.
func (*MockPatientService) EXPECT ¶
func (m *MockPatientService) EXPECT() *MockPatientServiceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockPatientServiceMockRecorder ¶
type MockPatientServiceMockRecorder struct {
// contains filtered or unexported fields
}
MockPatientServiceMockRecorder is the mock recorder for MockPatientService.
func (*MockPatientServiceMockRecorder) Create ¶
func (mr *MockPatientServiceMockRecorder) Create(ctx, patient any) *gomock.Call
Create indicates an expected call of Create.
type MockShareService ¶
type MockShareService struct {
// contains filtered or unexported fields
}
MockShareService is a mock of ShareService interface.
func NewMockShareService ¶
func NewMockShareService(ctrl *gomock.Controller) *MockShareService
NewMockShareService creates a new mock instance.
func (*MockShareService) EXPECT ¶
func (m *MockShareService) EXPECT() *MockShareServiceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockShareService) GetSharedResources ¶
func (m *MockShareService) GetSharedResources(ctx context.Context) (*domain.SharedResourcesResponse, error)
GetSharedResources mocks base method.
func (*MockShareService) Share ¶
func (m *MockShareService) Share(ctx context.Context, req domain.ShareRequest) (*domain.ShareResponse, error)
Share mocks base method.
type MockShareServiceMockRecorder ¶
type MockShareServiceMockRecorder struct {
// contains filtered or unexported fields
}
MockShareServiceMockRecorder is the mock recorder for MockShareService.
func (*MockShareServiceMockRecorder) GetSharedResources ¶
func (mr *MockShareServiceMockRecorder) GetSharedResources(ctx any) *gomock.Call
GetSharedResources indicates an expected call of GetSharedResources.
type MockTmpAccessClient ¶
type MockTmpAccessClient struct {
// contains filtered or unexported fields
}
MockTmpAccessClient is a mock of TmpAccessClient interface.
func NewMockTmpAccessClient ¶
func NewMockTmpAccessClient(ctrl *gomock.Controller) *MockTmpAccessClient
NewMockTmpAccessClient creates a new mock instance.
func (*MockTmpAccessClient) EXPECT ¶
func (m *MockTmpAccessClient) EXPECT() *MockTmpAccessClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockTmpAccessClient) GenerateTmpToken ¶
func (m *MockTmpAccessClient) GenerateTmpToken(ctx context.Context, data domain.GenerateTmpTokenRequest) (*domain.GenerateTmpTokenResponse, error)
GenerateTmpToken mocks base method.
type MockTmpAccessClientMockRecorder ¶
type MockTmpAccessClientMockRecorder struct {
// contains filtered or unexported fields
}
MockTmpAccessClientMockRecorder is the mock recorder for MockTmpAccessClient.
func (*MockTmpAccessClientMockRecorder) GenerateTmpToken ¶
func (mr *MockTmpAccessClientMockRecorder) GenerateTmpToken(ctx, data any) *gomock.Call
GenerateTmpToken indicates an expected call of GenerateTmpToken.
type ObservationRepository ¶
type ObservationRepository interface {
Create(ctx context.Context, obs *models.Observation) (*models.Observation, error)
GetByID(ctx context.Context, id string) (*models.Observation, error)
GetByIDs(ctx context.Context, ids []string) ([]models.Observation, error)
Update(ctx context.Context, obs *models.Observation) (*models.Observation, error)
Delete(ctx context.Context, id string) error
Search(ctx context.Context, patientID string, limit, offset int) ([]models.Observation, int64, error)
}
type ObservationService ¶
type ObservationService interface {
Create(ctx context.Context, obs *models.Observation) (*models.Observation, error)
Get(ctx context.Context, id string) (*models.Observation, error)
Update(ctx context.Context, obs *models.Observation) (*models.Observation, error)
Delete(ctx context.Context, id string) error
List(ctx context.Context, patientID string, limit, offset int) (*domain.ListResponse[models.Observation], error)
}
type PatientRepository ¶
type PatientService ¶
type ShareService ¶
type ShareService interface {
}
type TmpAccessClient ¶
type TmpAccessClient interface {
GenerateTmpToken(ctx context.Context, data domain.GenerateTmpTokenRequest) (*domain.GenerateTmpTokenResponse, error)
}